# Author : Dezmo 
# Name : Make Tank 1.0 (Beta)
# Description : A tool to create simple tank to origin (0,0,0)
# Menu Item : Draw->Make Tank 1.0
# Usage : 1. Specify dimensions according to imputbox
# Date : 9/19/2012
# Type : Tool
#-----------------------------------------------------------------------------
#Permission to use, copy, modify, and distribute this software for 
#any purpose and without fee is hereby granted, provided this notice 
#appears in all copies.
#THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
#IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
#WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#-----------------------------------------------------------------------------

#----------------------------------------------------------------------------
# Based on: (Thanks a lot! :-) )
#----------------------------------------------------------------------------
# Copyright 2004, ODM
# Author : ODM 
# email: odm@aitop.com
# http://www.aitop.com
# Name : Conee Tool 1.0 (Beta)
# Description : A tool to create cone Top
# Menu Item : Draw->Cone Top
# Usage : 1. Specify base diameter&top diameter and heightof conee.
# : 2. Click in model to select location of cone Top 1.0. (future version)
# Date : 8/30/2004
# Type : Tool
#----------------------------------------------------------------------------

require 'sketchup.rb'

#----------------------------------------------------------------------------

def create_tank
model = Sketchup.active_model
entities = model.active_entities
group = entities.add_group
entities = group.entities

model.start_operation "Create Tank" # Encapsulate a single UNDO operation.

prompts = ["Base Diameter ","Top Diameter ","Bottom Diameter ","Height cilinder ","Height top ","Height bottom ","Height leg ","Segments "] # Define prompts in the input box
values = [2000.mm,40.mm,100.mm,2000.mm,300.mm,300.mm,600.mm,24] # default values in the input box
results = inputbox prompts, values, "Tank Dimensions"
return if not results # This means that the user canceled the operation
base,top,bottom,height_cilinder,height_top,height_bottom,height_leg,segments= results

center_base = [0,0,0] # Center of base circle
center_basea = [0,0,height_leg] # Center of cone base 1 bottom cone
center_topa  = [0,0,(height_leg+height_bottom)] # Center of cone base 1 bottom cone
center_baseb = [0,0,(height_leg+height_bottom+0.001)] # Center of cone base 2 middle cone
center_topb  = [0,0,(height_leg+height_bottom+height_cilinder)] # Center of cone base 2 middle cone
center_basec = [0,0,(height_leg+height_bottom+height_cilinder+0.001)] # Center of cone base 3 top cone
center_topc  = [0,0,(height_leg+height_bottom+height_cilinder+height_top)] # Center of cone base 3 top cone
vector = [0,0,1] # Normal Vector 
radius_base = base/2 # Radius of Tank
radius_top=top/2 # Radius of top cone
radius_bottom=bottom/2 # Radius of bottom cone

base_circ = entities.add_circle(center_base, vector, radius_base, segments) # Base circle, just to see contur on floor
lines=entities.add_line(center_base,center_topc) # Center line to get grip points and height dimension easy

# 1 Bottom cone

cone_basea = entities.add_circle(center_basea, vector, radius_bottom, segments)
cone_topa = entities.add_circle(center_topa, vector, radius_base, segments)

face_basea = entities.add_face(cone_basea)
face_topa = entities.add_face(cone_topa)
ver_basea = face_basea.vertices
ver_topa=face_topa.vertices
lines = []
0.upto(ver_basea.length-1) do |a|
    lines=entities.add_line(ver_basea[a],ver_topa[a])
    entities[entities.length-1].find_faces
end

# 1 Bottom cone

# 2 Middle cone

cone_baseb = entities.add_circle(center_baseb, vector, radius_base, segments)
cone_topb = entities.add_circle(center_topb, vector, radius_base, segments)

face_baseb = entities.add_face(cone_baseb)
face_topb = entities.add_face(cone_topb)
ver_baseb = face_baseb.vertices
ver_topb=face_topb.vertices
lines = []
0.upto(ver_baseb.length-1) do |b|
    lines=entities.add_line(ver_baseb[b],ver_topb[b])
    entities[entities.length-1].find_faces
end

# 2 Middle cone

# 3 Top cone

cone_basec = entities.add_circle(center_basec, vector, radius_base, segments)
cone_topc = entities.add_circle(center_topc, vector, radius_top, segments)

face_basec = entities.add_face(cone_basec)
face_topc = entities.add_face(cone_topc)
ver_basec = face_basec.vertices
ver_topc=face_topc.vertices
lines = []
0.upto(ver_basec.length-1) do |c|
    lines=entities.add_line(ver_basec[c],ver_topc[c])
    entities[entities.length-1].find_faces
end

# 3 Top cone

model.commit_operation
end

if( not file_loaded?("maketank.rb") )

add_separator_to_menu("Draw")


UI.menu("Draw").add_item("Make Tank 1.0 ") { create_tank }

end

file_loaded("maketank.rb")