# Author : Dezmo 
# Name : Make Tank 1.4 (Beta)
# Description : A tool to create simple tank to origin (0,0,0)
# Menu Item : Draw->Make Tank 1.4
# Usage : 1. Specify dimensions according to imputbox
# Date first relase: 9/19/2012
# Date this relase: 9/25/2012
# Type : Tool


#-----------------------------------------------------------------------------
#Note please delete previous version from your plugin folder
#-----------------------------------------------------------------------------


# Changes: 1.0 First one ever :-)
# Changes: 1.0 >1.1 "Plays nice" (?)
# Changes: 1.1 >1.2 Units depens on Sketchup active model options 9/21/2012
# Changes: 1.2 >1.3 Add cilindrical legs as many as you want inside touch to base circle
# Changes: 1.3 >1.4 Add volume (bottom cone+cilinder) in liters and in cubic inches and put it as 3D text to top of the tank 
#(note volume is "real cilindrical" volume of bottom cone+cilinder, not depenst on segments, so it is not accurate if tank is eg. 4 segment)
# Now the main Tank group is named and splitted to "pieces" of named groups
# The initial values of inputbox is "mm"... sorry


#-----------------------------------------------------------------------------
#Permission to use, copy, modify, and distribute this software for 
#any purpose and without fee is hereby granted, provided this notice 
#appears in all copies.
#THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
#IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
#WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#-----------------------------------------------------------------------------

#----------------------------------------------------------------------------
# Based on: (Thanks a lot! :-) )
#----------------------------------------------------------------------------
# Copyright 2004, ODM
# Author : ODM 
# email: odm@aitop.com
# http://www.aitop.com
# Name : Conee Tool 1.0 (Beta)
# Description : A tool to create cone Top
# Menu Item : Draw->Cone Top
# Usage : 1. Specify base diameter&top diameter and heightof conee.
# : 2. Click in model to select location of cone Top 1.0. (future version)
# Date : 8/30/2004
# Type : Tool
#----------------------------------------------------------------------------

require 'sketchup.rb'

#----------------------------------------------------------------------------

module Dezmo_Tank

if( not file_loaded?("maketank4.rb") )
	add_separator_to_menu("Draw")
	UI.menu("Draw").add_item("Make Tank 1.4 ") { self.dezmo_create_tank }
end

def self.dezmo_create_tank
 # 4=m,3=cm,2=mm,1=feet,0=inches
    @unit=Sketchup.active_model.options["UnitsOptions"]["LengthUnit"]
	 # Units scale factor
		@scale = 1 if @unit == 0
		@scale = 12 if @unit == 1
		@scale = 0.0393700787401575 if @unit == 2
		@scale = 0.393700787401575 if @unit == 3
		@scale = 39.3700787401575 if @unit == 4


model = Sketchup.active_model
entities = model.active_entities
group = entities.add_group
group.name = "Tank"
entities = group.entities

model.start_operation "Create Tank" # Encapsulate a single UNDO operation.


prompts = ["Base Diameter ","Top Diameter ","Bottom Diameter ","Height cilinder ","Height top ","Height bottom ","Height leg ","Diameter of leg ","Number of legs","Segments "] # Define prompts in the input box
values = [2000.0,40.0,100.0,2000.0,300.0,300.0,600.0,200.0,3,24] # default values in the input box
results = inputbox prompts, values, "Tank Dimensions"
return if not results # This means that the user canceled the operation
base,top,bottom,height_cilinder,height_top,height_bottom,height_leg,leg,legs,segments= results

base=base*@scale
top=top*@scale
bottom=bottom*@scale
height_cilinder=height_cilinder*@scale
height_top=height_top*@scale
height_bottom=height_bottom*@scale
height_leg=height_leg*@scale
leg=leg*@scale


center_base = [0,0,0] # Center of base circle
center_basea = [0,0,height_leg] # Center of cone base 1 bottom cone
center_topa  = [0,0,(height_leg+height_bottom)] # Center of cone base 1 bottom cone
center_baseb = [0,0,(height_leg+height_bottom)] # Center of cone base 2 middle cone
center_topb  = [0,0,(height_leg+height_bottom+height_cilinder)] # Center of cone base 2 middle cone
center_basec = [0,0,(height_leg+height_bottom+height_cilinder)] # Center of cone base 3 top cone
center_topc  = [0,0,(height_leg+height_bottom+height_cilinder+height_top)] # Center of cone base 3 top cone
vector = [0,0,1] # Normal Vector 
radius_base = base/2 # Radius of Tank
radius_top=top/2 # Radius of top cone
radius_bottom=bottom/2 # Radius of bottom cone
radius_leg = leg/2 # Radius of legs
radius_legc=radius_base-radius_leg # Radius of legs center


# 0 LEGS

group0 = entities.add_group
group0.name = "Legs"
centerpoint = Geom::Point3d.new
vectorl = Geom::Vector3d.new 0,0,1
vectorn = vectorl.normalize!

(1..(legs)).each do |i|
 # Create a circle perpendicular to the normal or Z axis and pull

 centerpoint = [(radius_legc*Math.cos(2*i*(Math::PI)/legs)),(radius_legc*Math.sin(2*i*(Math::PI)/legs)),0]

 edges = group0.entities.add_circle centerpoint, vectorn, radius_leg
 face = group0.entities.add_face(edges)
 face.pushpull -(height_leg+height_bottom)
end


# 0 LEGS


base_circ = entities.add_circle(center_base, vector, radius_base, segments) # Base circle, just to see contur on floor
lines=entities.add_line(center_base,center_topc) # Center line to get grip points and height dimension easy

# 1 Bottom cone

group1 = entities.add_group
group1.name = "Bottom cone"
cone_basea = group1.entities.add_circle(center_basea, vector, radius_bottom, segments)
cone_topa = group1.entities.add_circle(center_topa, vector, radius_base, segments)

face_basea = group1.entities.add_face(cone_basea)
face_topa = group1.entities.add_face(cone_topa)
ver_basea = face_basea.vertices
ver_topa=face_topa.vertices
lines = []
0.upto(ver_basea.length-1) do |a|
    lines=group1.entities.add_line(ver_basea[a],ver_topa[a])
    group1.entities[group1.entities.length-1].find_faces
end


# 1 Bottom cone

# 2 Middle cone

group2 = entities.add_group
group2.name = "Cilinder"
cone_baseb = group2.entities.add_circle(center_baseb, vector, radius_base, segments)
cone_topb = group2.entities.add_circle(center_topb, vector, radius_base, segments)

face_baseb = group2.entities.add_face(cone_baseb)
face_topb = group2.entities.add_face(cone_topb)
ver_baseb = face_baseb.vertices
ver_topb=face_topb.vertices
lines = []
0.upto(ver_baseb.length-1) do |b|
    lines=group2.entities.add_line(ver_baseb[b],ver_topb[b])
    group2.entities[group2.entities.length-1].find_faces
end


# 2 Middle cone

# 3 Top cone


group3 = entities.add_group
group3.name = "Top cone"
cone_basec = group3.entities.add_circle(center_basec, vector, radius_base, segments)
cone_topc = group3.entities.add_circle(center_topc, vector, radius_top, segments)

face_basec = group3.entities.add_face(cone_basec)
face_topc = group3.entities.add_face(cone_topc)
ver_basec = face_basec.vertices
ver_topc=face_topc.vertices
lines = []

0.upto(ver_basec.length-1) do |c|
    lines = group3.entities.add_line(ver_basec[c],ver_topc[c])
    group3.entities[group3.entities.length-1].find_faces
end


# 3 Top cone



# Volume in liter


groupL = entities.add_group
groupL.name = "Volume Liter"
groupI = entities.add_group
groupI.name = "Volume cubic inch"
r1=base/2/0.0393700787401575
r2=bottom/2/0.0393700787401575
hc=height_cilinder/0.0393700787401575
hb=height_bottom/3/0.0393700787401575
x1=(((hb*(Math::PI)*((r1*r1)+(r1*r2)+(r2*r2))))/1000000).round
x2=((hc*(Math::PI)*r1*r1)/1000000).round
xL=x1+x2
vol_L= xL.to_s
xI=(xL*61.02374).round
vol_I= xI.to_s
hv=(base/20)
success = groupL.entities.add_3d_text(vol_L +'L'+"\n"+'.', TextAlignLeft, "Arial",   true, false, hv, 0.0, (height_leg+height_bottom+height_cilinder+height_top)+0.01, true, 0.0)
success = groupI.entities.add_3d_text(vol_I +'c.I', TextAlignLeft, "Arial",   true, false, hv, 0.0, (height_leg+height_bottom+height_cilinder+height_top)+0.01, true, 0.0)


# Volume in liter

model.commit_operation
end



file_loaded("maketank4.rb")

end # module